# 📖 Summary
- [📖 Summary](#📖-summary)
- [💼 About France Travail (ex: Pole Emploi)](#💼-about-france-travail-(ex:-pole-emploi))
  - [😍 Why is it a big deal for France Travail (ex: Pole Emploi) customers & partners?](#😍-why-is-it-a-big-deal-for-france-travail-(ex:-pole-emploi)-customers--partners)
- [🔧 How does it work?](#🔧-how-does-it-work)
  - [📊 Data integration capabilities:](#📊-data-integration-capabilities)
  - [🧠 Artificial Intelligence capabilities:](#🧠-artificial-intelligence-capabilities)
- [🔌 Connector Actions](#🔌-connector-actions)
- [💍 Quick Start Examples](#💍-quick-start-examples)
- [🔗 Useful Links](#🔗-useful-links)
- [👏 Special Thanks](#👏-special-thanks)


# 💼 About France Travail (ex: Pole Emploi)

> France Travail, formerly Pôle emploi until 31 December 2023, is a public administrative body responsible for employment in France. It was created on 19 December 2008 from the merger of the Agence nationale pour l'emploi and the Association pour l'emploi dans l'industrie et le commerce.

<p align="center">
<image src="https://github.com/user-attachments/assets/39acf8f4-6e53-4c04-afeb-56526a45eec8"width=90% height=100% >
</p>

## 😍 Why is it a big deal for France Travail (ex: Pole Emploi) customers & partners?

This new connector will enable:
- ⚡ A Fastlane Talent & Workforce data integration for France Travail (ex: Pole Emploi) customers & partners
- 🤖 Cutting-edge AI-powered Talent Experiences & Recruiter Experiences for France Travail (ex: Pole Emploi) customers

#  🔧 How does it work?
## 📊 Data integration capabilities:
- ⬅️ Send Profiles data from France Travail (ex: Pole Emploi) to a Destination of your choice.
- ➡️ Send Profiles data from a Source of your choice to France Travail (ex: Pole Emploi).
- ⬅️ Send Jobs data from France Travail (ex: Pole Emploi) to a Destination of your choice.
- ➡️ Send Jobs data from a Source of your choice to France Travail (ex: Pole Emploi).

<p align="center">

<image src=https://github.com/user-attachments/assets/108faf0a-b37c-4665-81e5-53412658ee57 width=90% height=100% >
</p>


## 🧠 Artificial Intelligence capabilities:
- Extract, Structure, and Categorize Talent & Workforce data
- Search, Score, and Match Profiles & Jobs with our APIs and AI Widgets (**Matching Custom Tab in France Travail (ex: Pole Emploi)**)


# 🔌 Connector Actions
<p align="center">

| Action | Description |
| ------- | ----------- |
| [**Create jobs in hrflow**](docs/create_jobs_in_hrflow.md) | Send **created** 'job(s)' _from_  _to_ HrFlow |
| [**Update jobs in hrflow**](docs/update_jobs_in_hrflow.md) | Send **updated** 'job(s)' _from_  _to_ HrFlow |
| [**Archive jobs in hrflow**](docs/archive_jobs_in_hrflow.md) | Send **archived** 'job(s)' _from_  _to_ HrFlow |


</p>


# 💍 Quick Start Examples

To make sure you can successfully run the latest versions of the example scripts, you have to **install the package from PyPi**.


To browse the examples of actions corresponding to released versions of 🤗 this connector, you just need to import the module like this :

<p align="center">
<image src=https://github.com/user-attachments/assets/3c5c085a-210e-4568-bf15-7dafaf8cea3e width=90% height=100% >
</p>

Once the connector module is imported, you can leverage all the different actions that it offers.

For more code details checkout connector code.


# 🔗 Useful Links

- 📄 Visit [France Travail (ex: Pole Emploi)](https://www.francetravail.fr/) to learn more.
- ⚙️ API documentation : (https://francetravail.io/produits-partages/documentation/utilisation-api-france-travail)
- 💻 [Connector code](https://github.com/Riminder/hrflow-connectors/tree/master/src/hrflow_connectors/v2/connectors/francetravail) on our Github.


# 👏 Special Thanks
- 💻 HrFlow.ai :  [Nedhir Ebnou](https://github.com/nedhirouebnou) - Software Engineer